@@ -179,7 +179,7 @@ LasReader::LasReader() : d(new Private)
 {}
 
 LasReader::~LasReader()
-{}
+{ cleanup(); }
 
 void LasReader::addArgs(ProgramArgs& args)
 {
@@ -330,13 +330,12 @@ void LasReader::initializeLocal(PointTableRef table, MetadataNode& m)
     d->header.fill(headerBuf, las::Header::Size14);
 
     uint64_t fileSize = Utils::fileSize(m_filename);
-    StringList errors = d->header.validate(fileSize, d->opts.nosrs);
+    StringList errors = d->header.validate(fileSize);
     if (errors.size())
         throwError(errors.front());
-    // Verify
-    if (!las::pointFormatSupported(d->header.pointFormat()))
-        throwError("Unsupported LAS input point format: " +
-            Utils::toString((int)d->header.pointFormat()) + ".");
+    if (d->header.has14PointFormat() && !d->header.useWkt())
+        log()->get(LogLevel::Warning) <<
+            "Global encoding WKT flag not set for point format 6 - 10.\n";
 
     // Set the queue function based on whether we're compressed or not.
     d->queueNext = d->header.dataCompressed() ?
@@ -629,7 +628,7 @@ void LasReader::readExtraBytesVlr()
 
     if (vlr->dataSize() % las::ExtraBytesSpecSize != 0)
     {
-        log()->get(LogLevel::Warning) << "Bad size for extra bytes VLR.  Ignoring.";
+        log()->get(LogLevel::Warning) << "Bad size for extra bytes VLR.  Ignoring.\n";
         return;
     }
 
@@ -639,7 +638,7 @@ void LasReader::readExtraBytesVlr()
     if (d->extraDims.size() && d->extraDims != extraDims)
         log()->get(LogLevel::Warning) << "Extra byte dimensions specified "
             "in pipeline and VLR don't match.  Ignoring pipeline-specified "
-            "dimensions";
+            "dimensions\n";
     d->extraDims = std::move(extraDims);
 }
 
@@ -727,10 +726,9 @@ point_count_t LasReader::read(PointViewPtr view, point_count_t count)
     for (i = 0; i < count; i++)
     {
         PointRef point = view->point(i);
-        PointId id = view->size();
         processOne(point);
         if (m_cb)
-            m_cb(*view, id);
+            m_cb(*view, view->size() - 1);
     }
     return (point_count_t)i;
 }
@@ -919,6 +917,11 @@ void LasReader::loadExtraDims(LeExtractor& istream, PointRef& point)
 
 
 void LasReader::done(PointTableRef)
+{
+    cleanup();
+}
+
+void LasReader::cleanup()
 {
     d->pool.join();
     if (d->isRemote)
