@@ -61,7 +61,6 @@ static PluginInfo const s_info{
 
 struct TileDBWriter::Args
 {
-    std::string m_arrayName;
     std::string m_cfgFileName;
     std::string m_cell_order;
     std::string m_tile_order;
@@ -90,6 +89,7 @@ struct TileDBWriter::Args
     bool m_use_time;
     bool m_time_first;
     bool m_combine_bit_fields;
+    bool m_allow_dups;
     uint64_t m_timeStamp = UINT64_MAX;
 };
 
@@ -106,9 +106,7 @@ std::string TileDBWriter::getName() const
 
 void TileDBWriter::addArgs(ProgramArgs& args)
 {
-    args.add("array_name", "TileDB array name", m_args->m_arrayName)
-        .setPositional();
-    args.addSynonym("array_name", "filename");
+    args.addSynonym("filename", "array_name");
     args.add("config_file", "TileDB configuration file location",
              m_args->m_cfgFileName);
     args.add("cell_order", "TileDB cell order", m_args->m_cell_order, "auto");
@@ -184,6 +182,9 @@ void TileDBWriter::addArgs(ProgramArgs& args)
     args.add("combine_bit_fields",
              "Combine all bit fields into a single 2 byte attribute",
              m_args->m_combine_bit_fields, true);
+    args.add("allow_dups", "Allow duplicate points (default is True)", m_args->m_allow_dups,
+             true);
+
 }
 
 void TileDBWriter::initialize()
@@ -292,7 +293,7 @@ void TileDBWriter::ready(pdal::BasePointTable& table)
 
         // Create schema and set basic properties.
         tiledb::ArraySchema schema{*m_ctx, TILEDB_SPARSE};
-        schema.set_allows_dups(true);
+        schema.set_allows_dups(m_args->m_allow_dups);
         schema.set_capacity(m_args->m_tile_capacity);
 
         // Set tile order.
@@ -491,22 +492,14 @@ void TileDBWriter::ready(pdal::BasePointTable& table)
         }
 
         // Create the TileDB array.
-        tiledb::Array::create(m_args->m_arrayName, schema);
+        tiledb::Array::create(arrayName(), schema);
     }
 
     // Open the array at the requested timestamp range.
-#if TILEDB_VERSION_MAJOR == 2 && TILEDB_VERSION_MINOR < 15
-    if (m_args->m_timeStamp != UINT64_MAX)
-        m_array.reset(new tiledb::Array(*m_ctx, m_args->m_arrayName,
-                                        TILEDB_WRITE, m_args->m_timeStamp));
-    else
-        m_array.reset(
-            new tiledb::Array(*m_ctx, m_args->m_arrayName, TILEDB_WRITE));
-#else
+
     m_array.reset(
-        new tiledb::Array(*m_ctx, m_args->m_arrayName, TILEDB_WRITE,
+        new tiledb::Array(*m_ctx, arrayName(), TILEDB_WRITE,
                           {tiledb::TimeTravelMarker(), m_args->m_timeStamp}));
-#endif
     const auto& schema = m_array->schema();
 
     for (const auto& dimBuffer : m_buffers)
@@ -576,7 +569,8 @@ void TileDBWriter::done(PointTableRef table)
                                   m.c_str());
             // add tiledb pointcloud tag
             std::string datasetType = "pointcloud";
-            m_array->put_metadata("dataset_type", TILEDB_STRING_UTF8, datasetType.size(), datasetType.data());
+            m_array->put_metadata("dataset_type", TILEDB_STRING_UTF8,
+                                  datasetType.size(), datasetType.data());
         }
         m_array->close();
     }
